@@ -3,6 +3,7 @@ from __future__ import absolute_import, unicode_literals
 
 import logging
 
+from edx_django_utils.db.read_replica import read_queries_only
 from six import text_type
 from xblock.field_data import FieldData
 
@@ -47,7 +48,7 @@ class DateLookupFieldData(FieldData):
         """
         super(DateLookupFieldData, self).__init__()
         if isinstance(defaults, DateLookupFieldData):
-            defaults = defaults._defaults  # pylint: disable=protected-access
+            defaults = defaults._defaults
         self._defaults = defaults
         self._load_dates(course_id, user, use_cached=use_cached)
 
@@ -55,9 +56,10 @@ class DateLookupFieldData(FieldData):
         """
         Load the dates from the database.
         """
-        dates = {}
-        for (location, field), date in api.get_dates_for_course(course_id, user, use_cached=use_cached).items():
-            dates[text_type(location), field] = date
+        with read_queries_only():
+            dates = {}
+            for (location, field), date in api.get_dates_for_course(course_id, user, use_cached=use_cached).items():
+                dates[text_type(location), field] = date
 
         self._course_dates = dates
 
@@ -121,7 +123,7 @@ class DateLookupFieldData(FieldData):
         return self._defaults.delete(block, name)
 
 
-class DateOverrideTransformer(object):
+class DateOverrideTransformer:
     """
     A transformer that loads date data in xblock.
     """
